@@ -26,30 +26,46 @@
 #' @examples
 #'
 #' library(huito)
-#' library(gsheet)
-#'
-#' url <- paste0("https://docs.google.com/spreadsheets/d/"
-#'        , "1q0EZmZBt52ca-0VbididjJy2jXTwf06laJpzvkQJWvc/edit#gid=107939497")
-#' fb <- gsheet2tbl(url)
 #' 
-#' # huito_fonts()
-#'
-#' label <- label_layout(data = fb, size = c(10, 2.5)) %>%
-#'          include_image(
-#'                value = "https://flavjack.github.io/inti/img/inkaverse.png"
-#'                , size = c(2.2, 2.2)
-#'                , position = c(1.2, 1.25)
-#'                ) %>%
-#'          include_barcode(
-#'                value = "qr-code"
-#'                , size = c(2.2, 2.2)
-#'                , position = c(8.3, 1.25)
-#'                ) %>%
-#'          include_text(value = "plots", position = c(9.7, 1.25), angle = 90, size = 15) %>%
-#'          include_text(value = "Inkaverse"
-#'          , position = c(3, 1.25), size = 18, opts = list(hjust = 0.0, vjust = 0.0)) %>%
-#'          label_print("sample")
+#' fb <- fieldbook
 #' 
+#' label <- fb %>% 
+#' label_layout(size = c(10, 2.5)
+#'              , border_color = "blue"
+#'              ) %>%
+#'   include_image(
+#'     value = "https://flavjack.github.io/inti/img/inkaverse.png"
+#'     , size = c(2.4, 2.4)
+#'     , position = c(1.2, 1.25)
+#'     ) %>%
+#'   include_barcode(
+#'     value = "barcode"
+#'     , size = c(2.5, 2.5)
+#'     , position = c(8.2, 1.25)
+#'     ) %>%
+#'   include_text(value = "plots"
+#'                , position = c(9.7, 1.25)
+#'                , angle = 90
+#'                , size = 15
+#'                , color = "red"
+#'                ) %>%
+#'   include_text(value = "Inkaverse"
+#'                , position = c(4.6, 2)
+#'                , size = 30
+#'                , color = "brown"
+#'                ) %>%
+#'   include_text(value = "condition"
+#'                , position = c(4.6, 1.2)
+#'                , size = 13
+#'                , color = "orange"
+#'                ) %>%
+#'   include_text(value = "genotypes"
+#'                , position = c(4.6, 0.5)
+#'                , size = 13
+#'                , color = "#009966"
+#'                ) %>% 
+#'                label_print(mode = "sample")
+#'   
 
 label_print <- function(label
                         , mode = "sample"
@@ -62,23 +78,7 @@ label_print <- function(label
                         , nlabels = NA
                         ) {
   
-  # test --------------------------------------------------------------------
-  
-  if(FALSE) {
-    
-    mode = "s"
-    margin = 0
-    paper = c(6, 6)
-    units = "cm"
-    filename = "label"
-    fonts = F
-    viewer = T
-    smpres = 200
-    
-    labels <- 3
-  }
-  
-  # args ------------------------------------------------------------------
+# args ------------------------------------------------------------------
   
   mode <- match.arg(mode, c("complete", "sample", "preview"))
   
@@ -268,7 +268,7 @@ label_print <- function(label
   
   # -------------------------------------------------------------------------
   
-  showtext::showtext_auto()
+  showtext::showtext_auto(enable = TRUE)
   
   if (mode =="sample"| mode == "preview") {
     
@@ -348,7 +348,7 @@ label_print <- function(label
       
     }
     
-    file_output <- filename %>% sub("\\..*", "", .) %>% paste0(., ".pdf")
+    file_output <- file.path(paste0(filename, ".pdf"))
     
     pdf <-1:length(grids) %>%
       purrr::map(function(x) {
@@ -386,7 +386,7 @@ label_print <- function(label
         , output = file_output
       ) 
     
-    showtext::showtext_auto(FALSE)
+    showtext::showtext_auto(enable = FALSE)
     
     path <- file_output
     
